==> tengits_common-0.0.12.tar.gz: lib/widgets/src/card_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_common/utils/src/image_utils.dart';

class TLCardStatisticsModel<T> {
  String? title;
  TextStyle? titleTextStyle;
  String? titleUnit;
  String? imagePath;
  List<T> items;

  TLCardStatisticsModel({
    this.title,
    this.titleTextStyle,
    this.titleUnit,
    this.items = const [],
  });
}

// 卡片统计
class TLCardstatistics<T> extends StatelessWidget {
  const TLCardstatistics({
    Key? key,
    required this.cardstatisticsModel,
    this.itemTitleTransformer,
    this.itemAmountTransformer,
    this.itemUnitTransformer,
    this.child,
  }) : super(key: key);

  final TLCardStatisticsModel cardstatisticsModel;
  final String Function(T item)? itemTitleTransformer;
  final String Function(T item)? itemAmountTransformer;
  final String Function(T item)? itemUnitTransformer;
  final Widget? child;

  @override
  Widget build(BuildContext context) {
    return Stack(children: [
      Container(
        height: 200.h,
        width: double.infinity,
        margin: EdgeInsets.only(left: 8.w, top: 20.h, right: 8.w, bottom: 16.h),
        padding: EdgeInsets.only(left: 8.w, top: 24.h, right: 8.w, bottom: 8.h),
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(8.r),
          image: DecorationImage(
            image: ImageUtils.getAssetImage("assets/common/images/total_bg.png"),
            fit: BoxFit.fill,
          ),
        ),
        alignment: Alignment.topLeft,
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Padding(
              padding: EdgeInsets.symmetric(horizontal: 8.h),
              child: Text(
                cardstatisticsModel.title ?? "",
                style: cardstatisticsModel.titleTextStyle ??
                    TextStyle(
                      fontFamily: 'dinFont',
                      color: Colors.white,
                      fontSize: 54.sp,
                      fontWeight: FontWeight.w600,
                    ),
                maxLines: 1,
              ),
            ),
            Padding(
              padding: EdgeInsets.symmetric(
                horizontal: 8.h,
              ),
              child: Text(
                cardstatisticsModel.titleUnit ?? "",
                style: TextStyle(
                  color: Colors.white,
                  fontSize: 13.sp,
                  height: 1.5.h,
                ),
              ),
            ),
          ],
        ),
      ),
      Positioned(
        right: 8.w,
        top: -3.h,
        child: Image(
          image: ImageUtils.getAssetImage(cardstatisticsModel.imagePath ?? ""),
          // width: 204.w,
          // height: 152.h,
          fit: BoxFit.fill,
        ),
      ),
      child ??
          Positioned(
            bottom: 24.h,
            left: 16.w,
            right: 16.w,
            height: 76.h,
            child: Container(
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(8.r),
                color: Colors.white.withOpacity(0.2),
              ),
              child: LayoutBuilder(builder: (BuildContext context, BoxConstraints constraints) {
                var viewWidth = constraints.maxWidth;
                return Stack(children: [
                  ListView(
                    physics: const NeverScrollableScrollPhysics(),
                    padding: const EdgeInsets.all(0),
                    scrollDirection: Axis.horizontal,
                    shrinkWrap: true,
                    itemExtent: (viewWidth / cardstatisticsModel.items.length),
                    children: cardstatisticsModel.items
                        .asMap()
                        .keys
                        .map(
                          (index) => Row(mainAxisAlignment: MainAxisAlignment.spaceAround, children: [
                            Column(
                              mainAxisSize: MainAxisSize.min,
                              crossAxisAlignment: CrossAxisAlignment.center,
                              mainAxisAlignment: MainAxisAlignment.center,
                              children: [
                                Text(
                                  itemTitleTransformer?.call(cardstatisticsModel.items[index] as T) ?? "",
                                  style: TextStyle(
                                    color: Colors.white,
                                    fontSize: 13.sp,
                                    height: 1.5.h,
                                  ),
                                ),
                                RichText(
                                  text: TextSpan(
                                      text: itemAmountTransformer?.call(cardstatisticsModel.items[index] as T) ?? "",
                                      style: TextStyle(
                                        color: Colors.white,
                                        fontSize: 23.sp,
                                      ),
                                      children: [
                                        TextSpan(
                                          text: itemUnitTransformer?.call(cardstatisticsModel.items[index] as T) ?? "",
                                          style: TextStyle(
                                            color: Colors.white,
                                            fontSize: 8.sp,
                                          ),
                                        )
                                      ]),
                                ),
                              ],
                            ),
                          ]),
                        )
                        .toList(),
                  ),
                  ...cardstatisticsModel.items
                      .asMap()
                      .keys
                      .map(
                        (index) => Positioned(
                          left: (index + 1) * (viewWidth / cardstatisticsModel.items.length),
                          bottom: 24.h,
                          child: (index < cardstatisticsModel.items.length - 1)
                              ? Container(
                                  width: 1.w,
                                  height: 24.h,
                                  color: Colors.white,
                                )
                              : const SizedBox.shrink(),
                        ),
                      )
                      .toList(),
                ]);
              }),
            ),
          ),
    ]);
  }
}

==> tengits_common-0.0.47.tar.gz: lib/widgets/src/card_widget.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:tengits_common/utils/src/image_utils.dart';

class TLCardStatisticsModel<T> {
  String? title;
  TextStyle? titleTextStyle;
  String? titleUnit;
  String? imagePath;
  List<T> items;

  TLCardStatisticsModel({
    this.title,
    this.titleTextStyle,
    this.titleUnit,
    this.items = const [],
  });
}

// 卡片统计
class TLCardstatistics<T> extends StatelessWidget {
  const TLCardstatistics({
    Key? key,
    required this.cardstatisticsModel,
    this.itemTitleTransformer,
    this.itemAmountTransformer,
    this.itemUnitTransformer,
    this.child,
    this.fontFamily = "dinFont"
  }) : super(key: key);

  final TLCardStatisticsModel cardstatisticsModel;
  final String Function(T item)? itemTitleTransformer;
  final String Function(T item)? itemAmountTransformer;
  final String Function(T item)? itemUnitTransformer;
  final Widget? child;
  final String fontFamily;

  @override
  Widget build(BuildContext context) {
    return Stack(children: [
      Container(
        height: 200.h,
        width: double.infinity,
        margin: EdgeInsets.only(left: 8.w, top: 20.h, right: 8.w, bottom: 16.h),
        padding: EdgeInsets.only(left: 8.w, top: 24.h, right: 8.w, bottom: 8.h),
        decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(8.r),
          image: DecorationImage(
            image: ImageUtils.getAssetImage("assets/images/total_bg.png", package: "tengits_common"),
            fit: BoxFit.fill,
          ),
        ),
        alignment: Alignment.topLeft,
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Padding(
              padding: EdgeInsets.symmetric(horizontal: 8.h),
              child: Text(
                cardstatisticsModel.title ?? "",
                style: cardstatisticsModel.titleTextStyle ??
                    TextStyle(
                      fontFamily: fontFamily,
                      color: Colors.white,
                      fontSize: 54.sp,
                      fontWeight: FontWeight.w600,
                    ),
                maxLines: 1,
              ),
            ),
            Padding(
              padding: EdgeInsets.symmetric(
                horizontal: 8.h,
              ),
              child: Text(
                cardstatisticsModel.titleUnit ?? "",
                style: TextStyle(
                  color: Colors.white,
                  fontSize: 13.sp,
                  height: 1.5.h,
                ),
              ),
            ),
          ],
        ),
      ),
      Positioned(
        right: 8.w,
        top: -3.h,
        child: Image(
          image: ImageUtils.getAssetImage(cardstatisticsModel.imagePath ?? ""),
          // width: 204.w,
          // height: 152.h,
          fit: BoxFit.fill,
        ),
      ),
      child ??
          Positioned(
            bottom: 24.h,
            left: 16.w,
            right: 16.w,
            height: 76.h,
            child: Container(
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(8.r),
                color: Colors.white.withOpacity(0.2),
              ),
              child: LayoutBuilder(builder: (BuildContext context, BoxConstraints constraints) {
                var viewWidth = constraints.maxWidth;
                return Stack(children: [
                  ListView(
                    physics: const NeverScrollableScrollPhysics(),
                    padding: const EdgeInsets.all(0),
                    scrollDirection: Axis.horizontal,
                    shrinkWrap: true,
                    itemExtent: (viewWidth / cardstatisticsModel.items.length),
                    children: cardstatisticsModel.items
                        .asMap()
                        .keys
                        .map(
                          (index) => Row(mainAxisAlignment: MainAxisAlignment.spaceAround, children: [
                            Column(
                              mainAxisSize: MainAxisSize.min,
                              crossAxisAlignment: CrossAxisAlignment.center,
                              mainAxisAlignment: MainAxisAlignment.center,
                              children: [
                                Text(
                                  itemTitleTransformer?.call(cardstatisticsModel.items[index] as T) ?? "",
                                  style: TextStyle(
                                    color: Colors.white,
                                    fontSize: 13.sp,
                                    height: 1.5.h,
                                  ),
                                ),
                                RichText(
                                  text: TextSpan(
                                      text: itemAmountTransformer?.call(cardstatisticsModel.items[index] as T) ?? "",
                                      style: TextStyle(
                                        fontFamily: fontFamily,
                                        color: Colors.white,
                                        fontSize: 24.sp,
                                      ),
                                      children: [
                                        TextSpan(
                                          text: itemUnitTransformer?.call(cardstatisticsModel.items[index] as T) ?? "",
                                          style: TextStyle(
                                            color: Colors.white,
                                            fontSize: 8.sp,
                                          ),
                                        )
                                      ]),
                                ),
                              ],
                            ),
                          ]),
                        )
                        .toList(),
                  ),
                  ...cardstatisticsModel.items
                      .asMap()
                      .keys
                      .map(
                        (index) => Positioned(
                          left: (index + 1) * (viewWidth / cardstatisticsModel.items.length),
                          bottom: 24.h,
                          child: (index < cardstatisticsModel.items.length - 1)
                              ? Container(
                                  width: 1.w,
                                  height: 24.h,
                                  color: Colors.white,
                                )
                              : const SizedBox.shrink(),
                        ),
                      )
                      .toList(),
                ]);
              }),
            ),
          ),
    ]);
  }
}
